@@ -2,9 +2,26 @@
 
 package Devel::AssertOS::OSFeatures::POSIXShellRedirection;
 
+$VERSION = '1.3';
+
 use Devel::CheckOS;
 
-use Devel::AssertOS qw(Unix Cygwin BeOS);
+sub matches { return qw(Unix Cygwin BeOS); }
+sub os_is { Devel::CheckOS::os_is(matches()); }
+Devel::CheckOS::die_unsupported() unless(os_is());
+
+sub expn {
+join("\n",
+"The operating system's normal shell(s) support POSIX-style redirection",
+"such as:",
+"  foo |  more    (piping from one command to another)",
+"  foo >  file    (redirection of STDOUT to a file)",
+"  foo 2> file    (redirection of STDERR to a file)",
+"  foo <  file    (redirection of STDIN from a file)",
+"and so on"
+)
+}
+
 
 =head1 NAME
 
@@ -24,22 +41,4 @@ This software is free-as-in-speech software, and may be used, distributed, and m
 
 =cut
 
-$VERSION = '1.2';
-
-sub os_is { 1; }
-
-sub expn {
-join("\n",
-"The operating system's normal shell(s) support POSIX-style redirection",
-"such as:",
-"  foo |  more    (piping from one command to another)",
-"  foo >  file    (redirection of STDOUT to a file)",
-"  foo 2> file    (redirection of STDERR to a file)",
-"  foo <  file    (redirection of STDIN from a file)",
-"and so on"
-)
-}
-
-Devel::CheckOS::die_unsupported() unless(os_is());
-
 1;
